package com.ximai.mes.remote;

import com.ximai.common.annotation.Log;
import com.ximai.common.enums.BusinessType;
import com.ximai.mes.remote.dto.*;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.PostMapping;

import java.util.List;

/**
 * erp远程调用接口
 */
@FeignClient(value = "erp-service", url = "${remote.erp.url}")
public interface ErpService {

    @Log(businessType = BusinessType.QUERY)
    @ApiOperation(value = "查询ERP供应商")
    @PostMapping(value = "/purma/getPurmaList")
    ErpResponseResult<List<MdVendorErpDto>> getVendorList(MdVendorErpQuery vendorErpQuery);

    @Log(businessType = BusinessType.QUERY)
    @ApiOperation(value = "查询ERP客户")
    @PostMapping(value = "/copma/getCopmaList")
    ErpResponseResult<List<MdClientErpDto>> getClientList(MdClientErpQuery clientErpQuery);

    @Log(businessType = BusinessType.QUERY)
    @ApiOperation(value = "查询ERP仓库")
    @PostMapping(value = "/cmsmc/getCmsmcList")
    ErpResponseResult<List<WmWarehouseErpDto>> getWarehouseList(WmWarehouseErpQuery warehouseErpQuery);


    @Log(businessType = BusinessType.QUERY)
    @ApiOperation(value = "查询ERP物料")
    @PostMapping(value = "/invmb/getInvmbList")
    ErpResponseResult<List<MdItemErpDto>> getItemList(MdItemErpQuery itemErpQuery);


    @Log(businessType = BusinessType.QUERY)
    @ApiOperation(value = "查询工单")
    @PostMapping(value = "/mocta/getMoctaList")
    ErpResponseResult<List<ProWorkorderErpDto>> getWorkorderList(ProWorkorderErpQuery workorderErpQuery);


    @Log(businessType = BusinessType.UPDATE)
    @ApiOperation(value = "工单同步标识")
    @PostMapping(value = "/mocta/syncMark")
    ErpResponseResult<Object> workorderSyncMark(ProWorkorderSyncMarkUpdate syncMarkUpdate);


    @Log(businessType = BusinessType.UPDATE)
    @ApiOperation(value = "物料同步标识")
    @PostMapping(value = "/invmb/syncMark")
    ErpResponseResult<Object> materialSyncMark(MdItemSyncMarkUpdate syncMarkUpdate);


    @Log(businessType = BusinessType.UPDATE)
    @ApiOperation(value = "工单状态更新")
    @PostMapping(value = "/mocta/updateState")
    ErpResponseResult<Object> updateState(ProWorkorderSyncMarkUpdate syncMarkUpdate);

    @Log(businessType = BusinessType.UPDATE)
    @ApiOperation(value = "请购单创建")
    @PostMapping(value = "/purta/create")
    ErpResponseResult<Object> purchasingRequisitionCreate(ProWorkorderSyncMarkUpdate syncMarkUpdate);

    @Log(businessType = BusinessType.UPDATE)
    @ApiOperation(value = "完工入库创建")
    @PostMapping(value = "/moctf/create")
    ErpResponseResult<Object> finishStockInCreate(ProWorkorderSyncMarkUpdate syncMarkUpdate);


}
